<?php declare(strict_types=1);

/**
 * Item View Page
 *
 * Retrieves and displays an item from a feed belonging to the current user
 */

use BitBadger\Documents\DocumentException;
use BitBadger\Documents\SQLite\Delete;
use BitBadger\Documents\SQLite\Patch;
use FeedReaderCentral\ItemWithFeed;
use FeedReaderCentral\Table;

include '../start.php';

FeedReaderCentral\Security::verifyUser();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        // "Keep as New" button sends a POST request to reset the is_read flag before going back to the item list
        if (ItemWithFeed::existsById($_POST['id'])) {
            Patch::byId(Table::ITEM, $_POST['id'], ['is_read' => 0]);
        }
        frc_redirect($_POST['from']);
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
}

$from = $_GET['from'] ?? '/';

if ($_SERVER['REQUEST_METHOD'] == 'DELETE') {
    try {
        if (ItemWithFeed::existsById($_GET['id'])) {
            Delete::byId(Table::ITEM, $_GET['id']);
        }
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
    frc_redirect($from);
}

if (!$item = ItemWithFeed::retrieveById($_GET['id'])) not_found();

try {
    Patch::byId(Table::ITEM, $_GET['id'], ['is_read' => 1]);
} catch (DocumentException $ex) {
    add_error("$ex");
}

$published = date_time($item->published_on);
$updated   = isset($item->updated_on) ? date_time($item->updated_on) : null;

page_head(htmlentities("$item->title | {$item->feed->title}")); ?>
<h1 class=item_heading>
    <span class=bookmark hx-get="/bookmark?id=<?=$_GET['id']?>" hx-trigger=load hx-target=this hx-swap=outerHTML
          hx-push-url=false></span>
    <a href="<?=$item->item_link?>" target=_blank rel=noopener><?=strip_tags($item->title)?></a><br>
</h1>
<div class=item_published>
    From <strong><?=htmlentities($item->feed->title)?></strong><br>
    Published <?=date_time($item->published_on)?><?=$updated && $updated != $published ? " (Updated $updated)" : ''?>
</div>
<article>
    <div class=item_content><?=str_replace('<a ', '<a target=_blank rel=noopener ', $item->content)?></div>
    <form class=action_buttons action=/item method=POST hx-post=/item>
        <input type=hidden name=id value=<?=$_GET['id']?>>
        <input type=hidden name=from value="<?=$from?>">
        <?=hx_get($from, 'Done')?>
        <button type=submit>Keep as New</button>
        <button type=button hx-delete=/item>Delete</button>
    </form>
</article><?php
page_foot();
